@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -17,12 +17,12 @@
 #include <QDebug>
 #include <QModelIndexList>
 #include <QPair>
+#include <QtCompilerDetection>
 #include <QtGlobal>
 #include <type_traits>
 #include <utility>
 #include "../../util/btassert.h"
 #include "../../util/btconnect.h"
-#include "../../util/macros.h"
 #include "../config/btconfigcore.h"
 #include "../drivers/btconstmoduleset.h"
 #include "../drivers/btmoduleset.h"
@@ -189,12 +189,12 @@ bool BtBookshelfTreeModel::setData(QModelIndex const & itemIndex,
     BT_ASSERT(itemIndex.isValid());
     using IP = QPair<Item *, QModelIndex>;
 
-    if (UNLIKELY(role != Qt::CheckStateRole))
+    if (Q_UNLIKELY(role != Qt::CheckStateRole))
         return false;
 
     bool ok;
     Qt::CheckState newState = static_cast<Qt::CheckState>(value.toInt(&ok));
-    if (UNLIKELY(!ok))
+    if (Q_UNLIKELY(!ok))
         return false;
 
     // Handle partially checked as checked here in setData():
@@ -472,7 +472,7 @@ void BtBookshelfTreeModel::removeModule(CSwordModuleInfo & module) {
 }
 
 Item & BtBookshelfTreeModel::getItem(QModelIndex const & index) const {
-    if (UNLIKELY(!index.isValid()))
+    if (Q_UNLIKELY(!index.isValid()))
         return *m_rootItem;
 
     Item * const item = static_cast<Item *>(index.internalPointer());
@@ -638,14 +638,16 @@ QDataStream & operator >>(QDataStream & is,
     // This is not entirely future proof, but good enough for the foreseeable
     // future, assuming that Qt does not change too much and users upgrade
     // relatively often enough.
+    static constexpr bool const isIntSize = std::is_same_v<int, Size>;
+
+    // If other strange platforms need to be supported, please let us know:
+    static_assert(isIntSize || sizeof(int) == 4, "Platform not supported");
+    static_assert(isIntSize || sizeof(Size) == 8, "Platform not supported");
+
     using U = std::underlying_type_t<BtBookshelfTreeModel::Group>;
-    if constexpr (std::is_same_v<int, Size>) {
+    if constexpr (isIntSize) {
         is >> size;
     } else {
-        // If other strange platforms need to be supported, please let us know:
-        static_assert(sizeof(int) == 4, "Platform not supported");
-        static_assert(sizeof(Size) == 8, "Platform not supported");
-
         // The following relies on Qt providing us a datastream which only
         // contains the serialized value and an optional ')' at the end. See
         // QSettingsPrivate::stringToVariant() in Qt 6.8.2 for details. Assuming
