@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -37,13 +37,7 @@ QVariant CategoryItem::data(int const role) const {
 bool CategoryItem::operator<(Item const & other) const {
     if (other.type() != ITEM_CATEGORY)
         return ITEM_CATEGORY < other.type();
-
-    auto & o = static_cast<CategoryItem const &>(other);
-    if (m_category == CSwordModuleInfo::UnknownCategory)
-        return false;
-    if (o.m_category == CSwordModuleInfo::UnknownCategory)
-        return true;
-    return m_category < o.m_category;
+    return m_category < static_cast<CategoryItem const &>(other).m_category;
 }
 
 } // namespace BookshelfModel
