@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -14,7 +14,6 @@
 
 #include <QIcon>
 #include "../../util/cresmgr.h"
-#include "../language.h"
 
 
 namespace BookshelfModel {
@@ -26,7 +25,7 @@ QVariant LanguageItem::data(int const role) const {
             return m_language->translatedName();
 
         case Qt::DecorationRole:
-            return CResMgr::modules::icon_moduleLanguage();
+            return CResMgr::icon_moduleLanguage();
 
         default:
             return Item::data(role);
