@@ -2,30 +2,30 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef MODULEITEM_H
-#define MODULEITEM_H
+#pragma once
 
 #include "item.h"
 
-#include "../drivers/cswordmoduleinfo.h"
-#include "btbookshelfmodel.h"
+#include <Qt>
+#include <QVariant>
 
 
 class BtBookshelfTreeModel;
+class CSwordModuleInfo;
 
 namespace BookshelfModel {
 
 class ModuleItem: public Item {
 
-public: /* Methods: */
+public: // methods:
 
     ModuleItem(CSwordModuleInfo & module,
                BtBookshelfTreeModel & parentModel)
@@ -39,15 +39,11 @@ public: /* Methods: */
     */
     QVariant data(int role = Qt::DisplayRole) const override;
 
-    inline CSwordModuleInfo & moduleInfo() const {
-        return m_moduleInfo;
-    }
+    CSwordModuleInfo & moduleInfo() const { return m_moduleInfo; }
 
-    inline bool fitFor(const CSwordModuleInfo &) const override {
-        return false;
-    }
+    bool fitFor(CSwordModuleInfo const &) const override { return false; }
 
-private: /* Fields: */
+private: // fields:
 
     CSwordModuleInfo & m_moduleInfo;
     BtBookshelfTreeModel & m_parentModel;
@@ -55,5 +51,3 @@ private: /* Fields: */
 };
 
 } // namespace BookshelfModel
-
-#endif // MODULEITEM_H
