@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -20,7 +20,6 @@
 #include <QMetaType>
 #include <QString>
 #include <QtGlobal>
-#include <vector>
 #include "../cswordmodulesearch.h"
 #include "../language.h"
 
@@ -85,7 +84,6 @@ public: // types:
 
     /** The module type. */
     enum ModuleType {
-        Unknown, /**< Fall back type for unknown modules */
         Bible, /**< Bible module */
         Commentary, /**< Commentary module */
         Lexicon, /**< Lexicon module */
@@ -143,18 +141,15 @@ public: // types:
     };
     Q_DECLARE_FLAGS(Features, Feature)
 
-    enum Category {
-        UnknownCategory = 0x0,  /**< Unknown or unset category. */
-        NoCategory      = 0x0,
-        Bibles          = 0x01,
-        Commentaries    = 0x02,
-        Books           = 0x04,
-        Lexicons        = 0x08,
-        Glossary        = 0x10,
-        DailyDevotional = 0x20,
-        Images          = 0x40,
-        Cult            = 0x80, /**< Cult / sect / questionable module. */
-        AllCategories   = 0xff
+    enum class Category {
+        Bibles           = 0x01,
+        Commentaries     = 0x02,
+        Books            = 0x04,
+        Lexicons         = 0x08,
+        Glossaries       = 0x10,
+        DailyDevotionals = 0x20,
+        MapsAndImages    = 0x40,
+        Questionable     = 0x80,
     };
     Q_DECLARE_FLAGS(Categories, Category)
 
@@ -356,23 +351,35 @@ wrong, or if the config file was write protected return false.
     */
     bool isUnicode() const noexcept;
 
-    /**
-      Returns an icon for this module.
-    */
-    QIcon moduleIcon() const { return CSwordModuleInfo::moduleIcon(*this); }
+    /** \returns an icon for this module based on it's isLocked() status. */
+    QIcon moduleIcon() const;
 
     /**
-      Returns an icon for the given module.
-      \param[in] module The module whose icon to return.
-    */
-    static QIcon const & moduleIcon(CSwordModuleInfo const & module);
-
-    /**
-      Returns an icon for the category of given module.
-      \param[in] module The module whose category icon to return.
+      \param[in] category The category whose icon to return.
+      \returns an ("unlocked") icon for the given category.
     */
     static QIcon const & categoryIcon(CSwordModuleInfo::Category category);
 
+    /**
+      \param[in] category The category whose icon to return.
+      \returns an "add" icon for the given category.
+    */
+    static QIcon const & categoryIconAdd(
+            CSwordModuleInfo::Category category);
+
+    /**
+      \param[in] category The category whose icon to return.
+      \returns a "locked" icon for the given category.
+    */
+    static QIcon const & categoryIconLocked(
+            CSwordModuleInfo::Category category);
+
+    /**
+      Returns an "add" category icon based on a module type.
+      \param[in] module The module whose category icon to return.
+    */
+    static QIcon const & categoryIconAdd(CSwordModuleInfo::ModuleType type);
+
     /**
       Returns a translated name for the given category.
       \param[in] module The category whose translated name to return.
