@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -13,7 +13,6 @@
 #include "cdisplaytemplatemgr.h"
 
 #include <algorithm>
-#include <memory>
 #include <QDir>
 #include <QFile>
 #include <QFileInfo>
@@ -22,20 +21,19 @@
 #include <QObject>
 #include <QStringList>
 #include <QTextStream>
-#include <set>
 #include "../../util/btassert.h"
 #include "../../util/directory.h"
 #include "../config/btconfig.h"
 #include "../drivers/btmodulelist.h"
 #include "../drivers/cswordmoduleinfo.h"
-#include "../language.h"
 #include "cswordbackend.h"
 
 
-#define CSSTEMPLATEBASE "Basic.tmpl"
 
 namespace {
 
+auto const cssTemplateBase = QStringLiteral("Basic.tmpl");
+
 inline QString readFileToString(const QString & filename) {
     QFile f(filename);
     return f.open(QIODevice::ReadOnly) ? QTextStream(&f).readAll() : QString();
@@ -47,8 +45,7 @@ auto const defaultTemplateName = QStringLiteral("Blue.css");
 
 CDisplayTemplateMgr * CDisplayTemplateMgr::m_instance = nullptr;
 
-CDisplayTemplateMgr::CDisplayTemplateMgr(QString & errorMessage) :
-    m_multiModuleHeaders(true) {
+CDisplayTemplateMgr::CDisplayTemplateMgr(QString & errorMessage) {
     BT_ASSERT(!m_instance);
     m_instance = this;
 
@@ -69,7 +66,7 @@ CDisplayTemplateMgr::CDisplayTemplateMgr(QString & errorMessage) :
                 loadTemplate(utd.canonicalPath() + '/' + file);
         }
 
-        if (!m_templateMap.contains(CSSTEMPLATEBASE)) {
+        if (!m_templateMap.contains(cssTemplateBase)) {
             errorMessage = QObject::tr("CSS base template not found!");
             return;
         }
@@ -94,7 +91,7 @@ CDisplayTemplateMgr::CDisplayTemplateMgr(QString & errorMessage) :
 
     // Create template names cache:
     m_availableTemplateNamesCache = m_templateMap.keys();
-    const bool b = m_availableTemplateNamesCache.removeOne(CSSTEMPLATEBASE);
+    const bool b = m_availableTemplateNamesCache.removeOne(cssTemplateBase);
     BT_ASSERT(b);
     m_availableTemplateNamesCache.append(m_cssMap.keys());
     std::sort(m_availableTemplateNamesCache.begin(),
@@ -104,10 +101,10 @@ CDisplayTemplateMgr::CDisplayTemplateMgr(QString & errorMessage) :
 }
 
 QString CDisplayTemplateMgr::fillTemplate(const QString & name,
-                                          const QString & content,
+                                          QString content,
                                           const Settings & settings) const
 {
-    BT_ASSERT(name != CSSTEMPLATEBASE);
+    BT_ASSERT(name != cssTemplateBase);
     BT_ASSERT(name.endsWith(QStringLiteral(".css"))
               || name.endsWith(QStringLiteral(".tmpl")));
     BT_ASSERT(!name.endsWith(QStringLiteral(".css"))
@@ -116,13 +113,9 @@ QString CDisplayTemplateMgr::fillTemplate(const QString & name,
               || m_templateMap.contains(name));
     const bool templateIsCss = name.endsWith(QStringLiteral(".css"));
 
-    QString displayTypeString;
     QString moduleName;
-
-    if (!settings.pageCSS_ID.isEmpty()) {
-        displayTypeString = settings.pageCSS_ID;
-    }
-    else {
+    auto displayTypeString = settings.pageCSS_ID;
+    if (displayTypeString.isEmpty()) {
         if (settings.modules.count()) {
             switch (settings.modules.first()->type()) {
 
@@ -147,10 +140,9 @@ QString CDisplayTemplateMgr::fillTemplate(const QString & name,
         }
     }
 
-    QString newContent = content;
     const int moduleCount = settings.modules.count();
 
-    if (moduleCount >= 2 && m_multiModuleHeaders) {
+    if (moduleCount >= 2) {
         //create header for the modules
         // qDebug() << "There were more than 1 module, create headers";
         QString header;
@@ -161,7 +153,7 @@ QString CDisplayTemplateMgr::fillTemplate(const QString & name,
                         .arg(QString::number(static_cast<int>(100.0 / moduleCount)),
                              mi->name()));
 
-        newContent = QStringLiteral("<table><tr>%1</tr>%2</table>")
+        content = QStringLiteral("<table><tr>%1</tr>%2</table>")
                      .arg(header, content);
     }
 
@@ -237,16 +229,16 @@ QString CDisplayTemplateMgr::fillTemplate(const QString & name,
     }
 
     namespace DU = util::directory;
-    QString output(m_templateMap[templateIsCss
-                                 ? QString(CSSTEMPLATEBASE)
-                                 : name]); // don't change the map's content directly, use a copy
+    auto output = m_templateMap[templateIsCss ? cssTemplateBase : name];
     output.replace(QStringLiteral("#TITLE#"), settings.title)
           .replace(QStringLiteral("#LANG_ABBREV#"), settings.langAbbrev)
           .replace(QStringLiteral("#DISPLAYTYPE#"), displayTypeString)
           .replace(QStringLiteral("#LANG_CSS#"), langCSS)
           .replace(QStringLiteral("#PAGE_DIRECTION#"),
-                   settings.textDirectionAsHtmlDirAttr())
-          .replace(QStringLiteral("#CONTENT#"), newContent)
+                   settings.textDirection == CSwordModuleInfo::LeftToRight
+                   ? QStringLiteral("ltr")
+                   : QStringLiteral("rtl"))
+          .replace(QStringLiteral("#CONTENT#"), content)
           .replace(QStringLiteral("#BODY_CLASSES#"),
                    QStringLiteral("%1 %1_%2").arg(displayTypeString,
                                                   moduleName))
@@ -284,7 +276,3 @@ void CDisplayTemplateMgr::loadCSSTemplate(const QString & filename) {
     if (fi.isReadable())
         m_cssMap.insert(fi.fileName(), readFileToString(filename));
 }
-
-void CDisplayTemplateMgr::setMultiModuleHeadersVisible(bool visible) {
-    m_multiModuleHeaders = visible;
-}
