@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -33,10 +33,6 @@ class CDisplayTemplateMgr {
         */
         struct Settings {
 
-            char const * textDirectionAsHtmlDirAttr() const noexcept {
-                return textDirection == CSwordModuleInfo::LeftToRight ? "ltr" : "rtl";
-            }
-
             /** The list of modules */
             BtConstModuleList modules;
 
@@ -82,7 +78,7 @@ class CDisplayTemplateMgr {
           \returns The full HTML template HTML code including the CSS data.
         */
         QString fillTemplate(const QString & name,
-                             const QString & content,
+                             QString content,
                              const Settings & settings) const;
 
         /**
@@ -97,12 +93,6 @@ class CDisplayTemplateMgr {
             BT_ASSERT(m_instance);
             return m_instance;
         }
-        /**
-          \brief Turn on or off displaying module names during parallel text rendering
-
-          \param visible display module names
-        */
-        void setMultiModuleHeadersVisible(bool visible);
 
     private: // methods:
 
@@ -112,7 +102,6 @@ class CDisplayTemplateMgr {
 
     private: // fields:
 
-        bool m_multiModuleHeaders;
         QHash<QString, QString> m_templateMap;
         QHash<QString, QString> m_cssMap;
         static CDisplayTemplateMgr * m_instance;
