@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -25,7 +25,5 @@ QString getBackgroundHighlightColor();
 QString getBackgroundHighlightColor(QString const & templateName);
 QString getForegroundColor();
 QString getForegroundColor(QString const & templateName);
-QString getCrossRefColor();
-QString getCrossRefColor(QString const & templateName);
 
 } /* namespace ColorManager */
