@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -17,9 +17,7 @@
 #include <QFileInfo>
 #include <QSet>
 #include <QString>
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
 #include <QStringDecoder>
-#endif
 #include <string_view>
 #include "../../util/btconnect.h"
 #include "../../util/directory.h"
@@ -381,8 +379,6 @@ void CSwordBackend::Private::reloadConfig() {
 
 // Return a list of used Sword dirs. Useful for the installer.
 QStringList CSwordBackend::swordDirList() const {
-    namespace DU = util::directory;
-
     // Get the set of sword directories that could contain modules:
     QSet<QString> swordDirSet;
     QList<QFileInfo> configs;
@@ -426,9 +422,7 @@ QStringList CSwordBackend::swordDirList() const {
     }
 
     // Search the sword.conf file(s) for sword directories that could contain modules
-    #if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
     static constexpr auto const decoderFlags = QStringDecoder::Flag::Stateless;
-    #endif
     for (auto const & fileInfo : configs) {
         /*
           Get all DataPath and AugmentPath entries from the config file and add
@@ -438,9 +432,6 @@ QStringList CSwordBackend::swordDirList() const {
 
         static auto const decodeConfEntry =
                 [](sword::SWBuf const & buf) {
-                    #if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-                    return QString::fromUtf8(buf.c_str());
-                    #else
                     QStringDecoder utf8Decoder("UTF-8", decoderFlags);
                     // Do not use auto here due to QTBUG-117705/QTBUG-117902:
                     QString result = utf8Decoder(buf.c_str());
@@ -451,7 +442,6 @@ QStringList CSwordBackend::swordDirList() const {
                     if (!cp1252Decoder.hasError())
                         return result;
                     return QString::fromLatin1(buf.c_str());
-                    #endif
                 };
 
         swordDirSet << QDir(decodeConfEntry(conf["Install"]["DataPath"])).absolutePath();
