@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -90,7 +90,7 @@ ReferenceManager::decodeHyperlink(QString const & hyperlink) {
     static auto const removeCaseInsensitivePrefix =
             [](QStringView & ref, QString const & prefix) {
                 if (ref.startsWith(prefix, Qt::CaseInsensitive)) {
-                    ref = ref.mid(prefix.size() - 1);
+                    ref = ref.mid(prefix.size());
                     return true;
                 }
                 return false;
