@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -325,8 +325,7 @@ QString BtModuleTextModel::lexiconData(const QModelIndex & index, int role) cons
         auto text = m_displayRendering.renderDisplayEntry(moduleList, keyName);
         text.replace(QStringLiteral("#CHAPTERTITLE#"), QString());
         text.replace(QStringLiteral("#TEXT_ALIGN#"), QStringLiteral("left"));
-        text = ColorManager::replaceColors(text);
-        return text;
+        return ColorManager::replaceColors(std::move(text));
     }
     else if (role == ModuleEntry::ReferenceRole){
         return keyName;
@@ -354,7 +353,7 @@ QString BtModuleTextModel::bookData(const QModelIndex & index, int role) const {
                 : Rendering::CTextRendering::KeyTreeItem::Settings::NoKey);
         text.replace(QStringLiteral("#CHAPTERTITLE#"), QString());
         text.replace(QStringLiteral("#TEXT_ALIGN#"), QStringLiteral("left"));
-        return text;
+        return ColorManager::replaceColors(std::move(text));
     }
     return QString();
 }
@@ -377,7 +376,6 @@ QString BtModuleTextModel::verseData(const QModelIndex & index, int role) const
     if (role >= ModuleEntry::TextRole && role <= ModuleEntry::Edit9Role) {
         if (verse == 0)
             return QString();
-        QString text;
 
         QString chapterTitle;
         if (verse == 1)
@@ -426,6 +424,7 @@ QString BtModuleTextModel::verseData(const QModelIndex & index, int role) const
             }
         }
 
+        QString text;
         if (!key.key().isEmpty())
             text +=
                 m_displayRendering.renderDisplayEntry(
@@ -437,8 +436,7 @@ QString BtModuleTextModel::verseData(const QModelIndex & index, int role) const
 
         text.replace(QStringLiteral("#CHAPTERTITLE#"), chapterTitle);
         text.replace(QStringLiteral("#TEXT_ALIGN#"), QStringLiteral("left"));
-        text = ColorManager::replaceColors(text);
-        return text;
+        return ColorManager::replaceColors(std::move(text));
     }
     return QString();
 }
