@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -30,7 +30,6 @@
 #include "../drivers/cswordlexiconmoduleinfo.h"
 #include "../drivers/cswordmoduleinfo.h"
 #include "../keys/cswordkey.h"
-#include "../language.h"
 #include "../managers/cdisplaytemplatemgr.h"
 #include "../managers/cswordbackend.h"
 #include "crossrefrendering.h"
@@ -345,7 +344,7 @@ QString decodeMorph(QString const & data) {
 
 QString decodeSwordReference(QString const & data) {
     static QRegularExpression const rx(
-        QStringLiteral(R"PCRE(sword://(bible|lexicon)/(.*?)/(.*?))PCRE"),
+        QStringLiteral(R"PCRE(sword://(bible|lexicon)/(.*)/(.*))PCRE"),
         QRegularExpression::CaseInsensitiveOption);
     if (auto const match = rx.match(data); match.hasMatch()) {
         if (auto * const module =
