@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -16,6 +16,9 @@
 
 #include <QList>
 #include <QPointer>
+#ifdef BUILD_TEXT_TO_SPEECH
+#include <QTextToSpeech>
+#endif
 #include <QTimer>
 #include "../backend/drivers/btmodulelist.h"
 #include "../backend/drivers/cswordmoduleinfo.h"
@@ -165,6 +168,7 @@ public: // Types:
         } view;
 
         struct { // Search menu:
+            QAction * searchActiveWindow;
             QAction * searchOpenWorks;
             QAction * searchStandardBible;
         } search;
@@ -270,6 +274,21 @@ public:
     void openSearchDialog(BtConstModuleList modules,
                           QString const & searchText = {});
 
+    #ifdef BUILD_TEXT_TO_SPEECH
+    /**
+      Speaks the given text.
+      \param[in] text The text to speak.
+     */
+    void speakText(QString const & text);
+
+    /**
+      Creates a QTextToSpeech instance, taking text-to-speech
+      settings into account.
+      \returns The QTextToSpeech instance.
+     */
+    static std::unique_ptr<QTextToSpeech> createTextToSpeechInstance();
+    #endif
+
 public Q_SLOTS:
 
     /** Opens the optionsdialog of BibleTime. */
@@ -419,6 +438,8 @@ private Q_SLOTS:
     void autoScrollPause();
     bool autoScrollAnyKey();
 
+    void slotSearchActiveWindow();
+
     /** Called when search button is pressed. */
     void slotSearchModules();
 
@@ -477,6 +498,10 @@ private: // fields:
     QAction * m_debugWidgetAction = nullptr;
     QPointer<QWidget> m_debugWindow;
 
+    #ifdef BUILD_TEXT_TO_SPEECH
+    std::unique_ptr<QTextToSpeech> m_textToSpeech;
+    #endif
+
 };
 
 extern template void BibleTime::autoScroll<true>();
