@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -132,11 +132,19 @@ BibleTime::ActionCollection::ActionCollection(
 
     // Search menu:
 
+    search.searchActiveWindow = new QAction(this);
+    search.searchActiveWindow->setIcon(
+                CResMgr::mainMenu::mainIndex::search::icon());
+    search.searchActiveWindow->setShortcut(
+                tr("Ctrl+O", "Search|Search works in active window/tab"));
+    addAction(QStringLiteral("searchActiveWindow"),
+              search.searchActiveWindow);
+
     search.searchOpenWorks = new QAction(this);
     search.searchOpenWorks->setIcon(
                 CResMgr::mainMenu::mainIndex::search::icon());
     search.searchOpenWorks->setShortcut(
-                tr("Ctrl+O", "Search|Search in open works"));
+                tr("Ctrl+Shift+O", "Search|Search in all open works"));
     addAction(QStringLiteral("searchOpenWorks"), search.searchOpenWorks);
 
     search.searchStandardBible = new QAction(this);
@@ -337,7 +345,12 @@ void BibleTime::ActionCollection::retranslateUi() {
     view.scroll.pauseAutoScroll->setText(tr("Pause auto scroll"));
     view.scroll.pauseAutoScroll->setToolTip(tr("Pause/resume auto scrolling"));
 
-    search.searchOpenWorks->setText(tr("Search in &open works..."));
+    search.searchActiveWindow->setText(
+                tr("&Search works in active window/tab..."));
+    search.searchActiveWindow->setToolTip(
+                tr("Search in all works in the active open window or tab"));
+
+    search.searchOpenWorks->setText(tr("Search in all &open works..."));
     search.searchOpenWorks->setToolTip(
                 tr("Search in all works that are currently open"));
 
@@ -431,9 +444,11 @@ void BibleTime::initView() {
     createCentralWidget();
 
     m_bookshelfDock = new BtBookshelfDockWidget(this);
+    m_bookshelfDock->setObjectName("bookshelfDock");
     addDockWidget(Qt::LeftDockWidgetArea, m_bookshelfDock);
 
     m_bookmarksDock = new QDockWidget(this);
+    m_bookmarksDock->setObjectName("bookmarksDock");
     m_bookmarksPage = new CBookmarkIndex(this);
     m_bookmarksDock->setWidget(m_bookmarksPage);
     addDockWidget(Qt::LeftDockWidgetArea, m_bookmarksDock);
@@ -441,6 +456,7 @@ void BibleTime::initView() {
     m_bookshelfDock->loadBookshelfState();
 
     m_magDock = new QDockWidget(this);
+    m_magDock->setObjectName("magDock");
     m_infoDisplay = new CInfoDisplay(this);
     m_infoDisplay->resize(150, 150);
     m_magDock->setWidget(m_infoDisplay);
@@ -488,6 +504,7 @@ void BibleTime::createMenuAndToolBar()
     menuBar();
 
     m_mainToolBar = createToolBar(this, true);
+    m_mainToolBar->setObjectName("mainToolBar");
     addToolBar(m_mainToolBar);
 
     // Set visibility of main window toolbars based on config
@@ -497,13 +514,16 @@ void BibleTime::createMenuAndToolBar()
                 true);
 
     m_navToolBar = createToolBar(this, visible);
+    m_navToolBar->setObjectName("navToolBar");
     addToolBar(m_navToolBar);
 
     m_worksToolBar = new BtModuleChooserBar(this);
+    m_worksToolBar->setObjectName("worksToolBar");
     m_worksToolBar->setVisible(visible);
     addToolBar(m_worksToolBar);
 
     m_toolsToolBar = createToolBar(this, visible);
+    m_toolsToolBar->setObjectName("toolsToolBar");
     addToolBar(m_toolsToolBar);
 }
 
@@ -606,6 +626,8 @@ void BibleTime::initActions() {
                this, &BibleTime::autoScrollPause);
 
     // Search menu actions:
+    BT_CONNECT(m_actions->search.searchActiveWindow, &QAction::triggered,
+               this, &BibleTime::slotSearchActiveWindow);
     BT_CONNECT(m_actions->search.searchOpenWorks, &QAction::triggered,
                this, &BibleTime::slotSearchModules);
     BT_CONNECT(m_actions->search.searchStandardBible,
@@ -739,6 +761,7 @@ void BibleTime::initMenubar() {
 
     // Search menu:
     m_searchMenu = new QMenu(this);
+    m_searchMenu->addAction(m_actions->search.searchActiveWindow);
     m_searchMenu->addAction(m_actions->search.searchOpenWorks);
     m_searchMenu->addAction(m_actions->search.searchStandardBible);
     menuBar()->addMenu(m_searchMenu);
@@ -787,18 +810,11 @@ void BibleTime::initMenubar() {
     BT_CONNECT(m_windowsMenu, &QMenu::aboutToShow,
                this,          &BibleTime::slotWindowMenuAboutToShow);
 
-    #ifndef Q_OS_MAC
     m_settingsMenu = new QMenu(this);
     m_settingsMenu->addAction(m_actions->settings.bookshelfManager);
     m_settingsMenu->addSeparator();
     m_settingsMenu->addAction(m_actions->settings.configureBibleTime);
     menuBar()->addMenu(m_settingsMenu);
-    #else
-    // On MAC OS, the settings actions will be moved to a system menu item.
-    // Therefore the settings menu would be empty, so we do not show it.
-    m_fileMenu->addAction(m_setPreferencesAction);
-    m_fileMenu->addAction(m_bookshelfWizardAction);
-    #endif
 
     // Help menu:
     m_helpMenu = new QMenu(this);
@@ -848,10 +864,7 @@ void BibleTime::retranslateUi() {
     m_windowLoadProfileMenu->setTitle(tr("Sw&itch session"));
     m_windowDeleteProfileMenu->setTitle(tr("&Delete session"));
 
-    #ifndef Q_OS_MAC
-    // This item is not present on Mac OS
     m_settingsMenu->setTitle(tr("Se&ttings"));
-    #endif
 
     m_helpMenu->setTitle(tr("&Help"));
 
