@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -31,18 +31,17 @@
 #include <QString>
 #include <Qt>
 #include <QtGlobal>
-#if defined(Q_OS_WIN) || defined(Q_OS_MAC)
+#ifdef Q_OS_WIN
 #include <QTextStream>
 #endif
 #ifdef Q_OS_WIN
 #include <windows.h>
 #endif
 #include "../backend/config/btconfig.h"
-#include "../backend/managers/cswordbackend.h"
 #include "../backend/managers/cdisplaytemplatemgr.h"
 #include "../util/btassert.h"
 #include "../util/bticons.h"
-#if defined(Q_OS_WIN) || defined(Q_OS_MAC)
+#ifdef Q_OS_WIN
 #include "../util/directory.h"
 #endif
 #include "messagedialog.h"
@@ -51,9 +50,6 @@
 // Sword includes:
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wextra-semi"
-#ifdef Q_OS_MAC
-    #include "localemgr.h"
-#endif
 #include <swlog.h>
 #pragma GCC diagnostic pop
 
@@ -124,11 +120,6 @@ BibleTimeApp::BibleTimeApp(int &argc, char **argv)
     setApplicationVersion(BT_VERSION);
     setDesktopFileName(QStringLiteral("info.bibletime.BibleTime"));
 
-    // Support for retina displays
-    #if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-    this->setAttribute(Qt::AA_UseHighDpiPixmaps);
-    #endif
-
     #ifdef Q_OS_WIN
     // On Windows, add a path for Qt plugins to be loaded from:
     addLibraryPath(applicationDirPath() + QStringLiteral("/plugins"));
@@ -149,13 +140,19 @@ BibleTimeApp::BibleTimeApp(int &argc, char **argv)
                 std::make_unique<QFile>(
                     QDir::home().filePath(
                         QStringLiteral("/BibleTime Debug.txt")));
-        debugStream->open(QIODevice::WriteOnly | QIODevice::Text);
-        qInstallMessageHandler(myMessageOutput);
+        if (debugStream->open(QIODevice::WriteOnly | QIODevice::Text)) {
+            qInstallMessageHandler(myMessageOutput);
+        } else {
+            qFatal() << "Failed to change message handler";
+        }
     }
     #else
     debugStream = std::make_unique<QFile>();
-    debugStream->open(stderr, QIODevice::WriteOnly | QIODevice::Text);
-    qInstallMessageHandler(myMessageOutput);
+    if (debugStream->open(stderr, QIODevice::WriteOnly | QIODevice::Text)) {
+        qInstallMessageHandler(myMessageOutput);
+    } else {
+        qFatal() << "Failed to change message handler";
+    }
     #endif
 }
 
@@ -285,7 +282,7 @@ void BibleTimeApp::initBackends() {
     // It also contains a DataPath to the %ProgramData%\Sword directory
     // If this is not done here, the sword locales.d won't be found
 
-    #if defined(Q_OS_WIN) || defined(Q_OS_MAC)
+    #ifdef Q_OS_WIN
     {
         QFile file(
                 util::directory::getUserHomeSwordDir().filePath(
@@ -294,16 +291,11 @@ void BibleTimeApp::initBackends() {
         {
             QTextStream(&file)
                 << QStringLiteral("\n[Install]\nDataPath=")
-            #if defined(Q_OS_WIN)
                 << QDir::toNativeSeparators(
                        util::directory::getSharedSwordDir().absolutePath())
                 << QStringLiteral("\nLocalePath=")
                 << QDir::toNativeSeparators(
                        util::directory::getApplicationSwordDir().absolutePath())
-            #elif defined(Q_OS_MAC)
-                << QDir::toNativeSeparators(
-                       util::directory::getUserHomeSwordDir().absolutePath())
-            #endif
                 << '\n';
         }
     }
@@ -313,12 +305,6 @@ void BibleTimeApp::initBackends() {
                                               ? sword::SWLog::LOG_DEBUG
                                               : sword::SWLog::LOG_ERROR);
 
-#ifdef Q_OS_MAC
-    // set a LocaleMgr with a fixed path to the locales.d of the DMG image on MacOS
-    qDebug() << "Using sword locales dir: " << util::directory::getSwordLocalesDir().absolutePath().toUtf8();
-    sword::LocaleMgr::setSystemLocaleMgr(new sword::LocaleMgr(util::directory::getSwordLocalesDir().absolutePath().toUtf8()));
-#endif
-
     /*
       Set book names language if not set. This is a hack. We do this call here,
       because we need to keep the setting displayed in BtLanguageSettingsPage in
