@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -221,8 +221,8 @@ CBookmarkIndex::CBookmarkIndex(QWidget * const parent)
                       BT_ASSERT(!tree.empty());
 
                       BtPrinter{btConfig().getDisplayOptions(),
-                                btConfig().getFilterOptions(),
-                                this}.printKeyTree(tree);
+                                btConfig().getFilterOptions()}
+                          .printKeyTree(tree);
                   });
     m_popup->addSeparator();
     addMenuAction(DeleteEntries, tr("Remove selected items..."),
@@ -374,11 +374,7 @@ void CBookmarkIndex::dragMoveEvent(QDragMoveEvent * event) {
     event->accept();
 
     // Do this to paint the arrow:
-    #if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-    m_dragMovementPosition = event->pos();
-    #else
     m_dragMovementPosition = event->position().toPoint();
-    #endif
     viewport()->update();
 }
 
@@ -456,11 +452,7 @@ void CBookmarkIndex::dropEvent(QDropEvent * event) {
                        [this](QModelIndex const & index) { expand(index); });
     auto cleanup = qScopeGuard([&connection]() noexcept
                                { disconnect(connection); });
-    #if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-    auto const pos = event->pos();
-    #else
     auto const pos = event->position().toPoint();
-    #endif
     auto const index = indexAt(pos);
     QModelIndex parentIndex;
     int indexUnderParent = 0;
