@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -12,19 +12,18 @@
 
 #include "btmoduleindexdialog.h"
 
+#include <array>
 #include <QApplication>
-#include <QMutexLocker>
-#include "../backend/managers/cswordbackend.h"
+#include <utility>
+#include "../backend/drivers/cswordmoduleinfo.h"
 #include "../util/btassert.h"
 #include "../util/btconnect.h"
+#include "../util/btdebugonly.h"
 #include "messagedialog.h"
 
 
 bool BtModuleIndexDialog::indexAllModules(const QList<CSwordModuleInfo *> &modules)
 {
-    static QMutex mutex;
-    QMutexLocker lock(&mutex);
-
     if (modules.empty()) return true;
 
     BtModuleIndexDialog d(modules.size());
@@ -47,7 +46,7 @@ bool BtModuleIndexDialog::indexAllModulesPrivate(const QList<CSwordModuleInfo*>
     bool success = true;
 
     QList <CSwordModuleInfo*> indexedModules;
-    Q_FOREACH(CSwordModuleInfo * const m, modules) {
+    for (auto * const m : modules) {
         BT_ASSERT(!m->hasIndex());
 
         /*
@@ -56,10 +55,21 @@ bool BtModuleIndexDialog::indexAllModulesPrivate(const QList<CSwordModuleInfo*>
         */
         indexedModules.append(m);
 
-        BT_CONNECT(this, SIGNAL(canceled()), m, SLOT(cancelIndexing()));
-        BT_CONNECT(m, SIGNAL(indexingFinished()), this, SLOT(slotFinished()));
-        BT_CONNECT(m,    SIGNAL(indexingProgress(int)),
-                   this, SLOT(slotModuleProgress(int)));
+        std::array<QMetaObject::Connection, 3u> connections{
+                BT_CONNECT(this, &BtModuleIndexDialog::canceled,
+                           m /* needed */,  [m]{ m->cancelIndexing(); }),
+                BT_CONNECT(m, &CSwordModuleInfo::indexingFinished,
+                           this, // needed
+                           [this]{
+                               setValue(m_currentModuleIndex * 100 + 100);
+                               qApp->processEvents();
+                           }),
+                BT_CONNECT(m, &CSwordModuleInfo::indexingProgress,
+                           this, // needed
+                           [this](int percentage) {
+                               setValue(m_currentModuleIndex * 100 + percentage);
+                               qApp->processEvents();
+                           })};
 
         // Single module indexing blocks until finished:
         setLabelText(tr("Creating index for work: %1").arg(m->name()));
@@ -85,32 +95,21 @@ bool BtModuleIndexDialog::indexAllModulesPrivate(const QList<CSwordModuleInfo*>
 
         m_currentModuleIndex++;
 
-        disconnect(this, SIGNAL(canceled()),
-                   m,    SLOT(cancelIndexing()));
-        disconnect(m,    SIGNAL(indexingFinished()),
-                   this, SLOT(slotFinished()));
-        disconnect(m,    SIGNAL(indexingProgress(int)),
-                   this, SLOT(slotModuleProgress(int)));
+        for (auto & connection : connections) {
+            BT_DEBUG_ONLY(auto const r =) disconnect(std::move(connection));
+            BT_ASSERT(r);
+        }
 
         if (wasCanceled()) success = false;
 
         if (!success) break;
     }
 
-    if (!success)
+    if (!success) {
         // Delete already created indices:
-        Q_FOREACH(CSwordModuleInfo * const m, indexedModules)
+        for (auto * const m : indexedModules)
             if (m->hasIndex())
                 m->deleteIndex();
+    }
     return success;
 }
-
-void BtModuleIndexDialog::slotModuleProgress(int percentage) {
-    setValue(m_currentModuleIndex * 100 + percentage);
-    qApp->processEvents();
-}
-
-void BtModuleIndexDialog::slotFinished() {
-    setValue(m_currentModuleIndex * 100 + 100);
-    qApp->processEvents();
-}
