@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -34,10 +34,8 @@ inline FilterOptions mangleFilterOptions(FilterOptions fo) {
 } // anonymous namespace
 
 BtPrinter::BtPrinter(DisplayOptions const & displayOptions,
-                     FilterOptions const & filterOptions,
-                     QObject * const parent)
-        : QObject{parent}
-        , CDisplayRendering{displayOptions, mangleFilterOptions(filterOptions)}
+                     FilterOptions const & filterOptions)
+        : CDisplayRendering{displayOptions, mangleFilterOptions(filterOptions)}
 {}
 
 void BtPrinter::printKeyTree(KeyTree const & tree) {
