@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -12,20 +12,16 @@
 
 #pragma once
 
-#include <QObject>
 #include "../backend/rendering/cdisplayrendering.h"
 
 
 /** \brief Manages the print item queue and printing. */
-class BtPrinter final: public QObject, public Rendering::CDisplayRendering {
-
-    Q_OBJECT
+class BtPrinter final: public Rendering::CDisplayRendering {
 
 public: // methods:
 
     BtPrinter(DisplayOptions const & displayOptions,
-              FilterOptions const & filterOptions,
-              QObject * const parent = nullptr);
+              FilterOptions const & filterOptions);
 
     void printKeyTree(KeyTree const &);
 
