@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -12,20 +12,24 @@
 
 #include "cmdiarea.h"
 
+#include <QAction>
 #include <QEvent>
+#include <QFlags>
+#include <QKeySequence>
 #include <QMdiSubWindow>
 #include <QMenu>
+#include <QPoint>
+#include <QRect>
+#include <QSize>
 #include <QStyle>
-#include <QtGlobal>
-#include <QtMath>
-#include <QTabBar>
 #include <QTimer>
-#include <QToolBar>
+#include <QWidget>
 #include <QWindowStateChangeEvent>
+#include "../util/btassert.h"
 #include "../util/btconnect.h"
 #include "bibletime.h"
-#include "displaywindow/btmodulechooserbar.h"
-#include "display/cdisplay.h"
+#include "displaywindow/cdisplaywindow.h"
+#include "display/btmodelviewreaddisplay.h"
 
 
 namespace {
@@ -43,8 +47,11 @@ CMDIArea::CMDIArea(BibleTime * parent)
         , m_activeWindow(nullptr)
         , m_bibleTime(parent)
 {
-    // Set document-style tabs (for Mac):
-    setDocumentMode(true);
+    setFocusPolicy(Qt::ClickFocus);
+
+    setDocumentMode(true); // Document-style tabs for Mac
+    setTabsClosable(true);
+    setTabsMovable(true);
 
     /*
       Activate windows based on the history of activation, e.g. when one has window A
@@ -56,31 +63,45 @@ CMDIArea::CMDIArea(BibleTime * parent)
     setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
     setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
 
-    BT_CONNECT(this, SIGNAL(subWindowActivated(QMdiSubWindow *)),
-               this, SLOT(slotSubWindowActivated(QMdiSubWindow *)));
+    BT_CONNECT(this, &QMdiArea::subWindowActivated,
+               [this](QMdiSubWindow* client) {
+                   if (subWindowList().isEmpty())
+                       m_bibleTime->clearMdiToolBars();
+
+                   if (client == nullptr) {
+                       return;
+                   }
+                   Q_EMIT sigSetToplevelCaption( client->windowTitle().trimmed() );
+
+                   // Notify child window it is active
+                   CDisplayWindow* const activeWindow = getDisplayWindow(client);
+                   if (activeWindow != nullptr && activeWindow != m_activeWindow) {
+                       m_activeWindow = activeWindow;
+                       activeWindow->windowActivated();
+                   }
+               });
 }
 
-void CMDIArea::fixSystemMenu(QMdiSubWindow* subWindow) {
+QMdiSubWindow * CMDIArea::addDisplayWindow(CDisplayWindow * const displayWindow)
+{
+    QMdiSubWindow * const subWindow = addSubWindow(displayWindow);
+    subWindow->setWindowIcon(displayWindow->windowIcon());
+    BT_CONNECT(displayWindow, &CDisplayWindow::windowIconChanged,
+               subWindow,     &QMdiSubWindow::setWindowIcon);
+
     // Change Qt QMdiSubWindow Close action to have no shortcuts
     // This makes our closeWindow actions with Ctrl-W work correctly
-    Q_FOREACH(QAction * const action, subWindow->systemMenu()->actions()) {
-        if (action->text().contains("Close")) {
+    for (auto * const action : subWindow->systemMenu()->actions()) {
+        if (action->text().contains(QStringLiteral("Close"))) {
             action->setShortcuts(QList<QKeySequence>());
             break;
         }
     }
-}
-
-QMdiSubWindow * CMDIArea::addSubWindow(QWidget * widget,
-                                       Qt::WindowFlags windowFlags)
-{
-    QMdiSubWindow * const subWindow = QMdiArea::addSubWindow(widget, windowFlags);
-    subWindow->installEventFilter(this);
-    fixSystemMenu(subWindow);
 
     // Manual arrangement mode
-    enableWindowMinMaxFlags(true);
     if (m_mdiArrangementMode == ArrangementModeManual) {
+        enableWindowMinMaxFlags(true);
+
         // Note that the window size/maximization may be changed later by a session restore.
         // If we already have an active window, make the new one simular to it
         if (activeSubWindow()) {
@@ -122,27 +143,12 @@ void CMDIArea::setMDIArrangementMode( const MDIArrangementMode newArrangementMod
             break;
         case ArrangementModeTabbed:
             setViewMode(QMdiArea::TabbedView);
-            for (auto win : subWindowList())
-                win->showMaximized();
             break;
         default:
             setViewMode(QMdiArea::SubWindowView);
             triggerWindowUpdate();
             break;
     }
-    Q_FOREACH(QTabBar * const tab, findChildren<QTabBar *>()) {
-        QObject* parent = tab->parent();
-        if (parent == this)
-            tab->setTabsClosable(true);
-    }
-}
-
-void CMDIArea::closeTab(int i) {
-   QMdiSubWindow *sub = subWindowList()[i];
-   QWidget *win = sub->widget();
-   win->close();
-   setActiveSubWindow(sub);
-   closeActiveSubWindow();
 }
 
 void CMDIArea::myTileVertical() {
@@ -161,7 +167,7 @@ void CMDIArea::myTileVertical() {
 
     const int widthForEach = width() / windows.count();
     int x = 0;
-    Q_FOREACH (QMdiSubWindow * const window, windows) {
+    for (auto * const window : windows) {
         window->showNormal();
 
         const int preferredWidth = window->minimumWidth() + window->baseSize().width();
@@ -194,7 +200,7 @@ void CMDIArea::myTileHorizontal() {
 
     const int heightForEach = height() / windows.count();
     int y = 0;
-    Q_FOREACH (QMdiSubWindow * const window, windows) {
+    for (auto * const window : windows) {
         window->showNormal();
 
         const int preferredHeight = window->minimumHeight() + window->baseSize().height();
@@ -293,7 +299,7 @@ void CMDIArea::myCascade() {
         unsigned int x = 0;
         unsigned int y = 0;
 
-        Q_FOREACH (QMdiSubWindow * const window, windows) {
+        for (auto * const window : windows) {
             if (window == active) { //leave out the active window which should be the top window
                 continue;
             }
@@ -316,10 +322,10 @@ void CMDIArea::myCascade() {
 
 void CMDIArea::emitWindowCaptionChanged() {
     if (activeSubWindow()) {
-        emit sigSetToplevelCaption(activeSubWindow()->windowTitle());
+        Q_EMIT sigSetToplevelCaption(activeSubWindow()->windowTitle());
     }
     else {
-        emit sigSetToplevelCaption(QString());
+        Q_EMIT sigSetToplevelCaption(QString());
     }
 }
 
@@ -327,47 +333,23 @@ QList<QMdiSubWindow*> CMDIArea::usableWindowList() const {
     //Take care: when new windows are added, they will not appear
     //in subWindowList() when their ChildAdded-Event is triggered
     QList<QMdiSubWindow*> ret;
-    Q_FOREACH(QMdiSubWindow * const w, subWindowList())
+    for (auto * const w : subWindowList())
         if (!w->isHidden())
             ret.append(w);
     return ret;
 }
 
-void CMDIArea::slotSubWindowActivated(QMdiSubWindow* client) {
-    if (subWindowList().isEmpty())
-        m_bibleTime->clearMdiToolBars();
+void CMDIArea::findNextTextInActiveWindow() { findTextInActiveWindow(false); }
 
-    if (client == nullptr) {
-        return;
-    }
-    emit sigSetToplevelCaption( client->windowTitle().trimmed() );
-
-    // Notify child window it is active
-    CDisplayWindow* const activeWindow = getDisplayWindow(client);
-    if (activeWindow != nullptr && activeWindow != m_activeWindow) {
-        m_activeWindow = activeWindow;
-        activeWindow->windowActivated();
-    }
-}
-
-void CMDIArea::findNextTextInActiveWindow(QString const & text, bool cs)
-{ findTextInActiveWindow(text, cs, false); }
-
-void CMDIArea::findPreviousTextInActiveWindow(QString const & text, bool cs)
-{ findTextInActiveWindow(text, cs, true); }
+void CMDIArea::findPreviousTextInActiveWindow() { findTextInActiveWindow(true);}
 
 void CMDIArea::highlightTextInActiveWindow(const QString& text, bool caseSensitive) {
     CDisplayWindow* const displayWindow = getDisplayWindow(activeSubWindow());
     displayWindow->displayWidget()->highlightText(text, caseSensitive);
 }
 
-void CMDIArea::findTextInActiveWindow(QString const & text,
-                                      bool caseSensitive,
-                                      bool backward)
-{
-    CDisplayWindow* const displayWindow = getDisplayWindow(activeSubWindow());
-    displayWindow->displayWidget()->findText(text, caseSensitive, backward);
-}
+void CMDIArea::findTextInActiveWindow(bool const backward)
+{ getDisplayWindow(activeSubWindow())->displayWidget()->findText(backward); }
 
 void CMDIArea::resizeEvent(QResizeEvent* e) {
     /*
@@ -402,7 +384,7 @@ bool CMDIArea::eventFilter(QObject *o, QEvent *e) {
             /*
               Do not handle window activation or deactivation here, it will
               produce wrong results because this event is handled too early. Let
-              slotSubWindowActivated() handle this.
+              lambda connected to subWindowActivated() handle this.
             */
 
             // Check if subwindow was maximized or un-maximized:
@@ -422,31 +404,30 @@ bool CMDIArea::eventFilter(QObject *o, QEvent *e) {
             break;
         case QEvent::WindowTitleChange:
             if (o == activeSubWindow()) {
-                emit sigSetToplevelCaption(w->windowTitle());
+                Q_EMIT sigSetToplevelCaption(w->windowTitle());
             }
-            return QMdiArea::eventFilter(o, e);
             break;
         default:
             break;
     }
 
-    return false; // Don't filter the event out
+    return QMdiArea::eventFilter(o, e);
 }
 
 void CMDIArea::triggerWindowUpdate() {
     if (updatesEnabled()) {
         switch (m_mdiArrangementMode) {
             case ArrangementModeTileVertical:
-                QTimer::singleShot(0, this, SLOT(myTileVertical()));
+                QTimer::singleShot(0, this, &CMDIArea::myTileVertical);
                 break;
             case ArrangementModeTileHorizontal:
-                QTimer::singleShot(0, this, SLOT(myTileHorizontal()));
+                QTimer::singleShot(0, this, &CMDIArea::myTileHorizontal);
                 break;
             case ArrangementModeTile:
-                QTimer::singleShot(0, this, SLOT(myTile()));
+                QTimer::singleShot(0, this, &CMDIArea::myTile);
                 break;
             case ArrangementModeCascade:
-                QTimer::singleShot(0, this, SLOT(myCascade()));
+                QTimer::singleShot(0, this, &CMDIArea::myCascade);
                 break;
             default:
                 break;
@@ -456,7 +437,7 @@ void CMDIArea::triggerWindowUpdate() {
 
 void CMDIArea::enableWindowMinMaxFlags(bool enable)
 {
-    Q_FOREACH (QMdiSubWindow * const subWindow, subWindowList()) {
+    for (auto * const subWindow : subWindowList()) {
         Qt::WindowFlags flags = subWindow->windowFlags();
         if (enable) {
             flags |= (Qt::WindowMinimizeButtonHint | Qt::WindowMaximizeButtonHint);
