@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -14,6 +14,11 @@
 
 #include <QTextEdit>
 
+#include <QPointF>
+
+
+class QQuickItem;
+class QQuickWidget;
 
 class DebugWindow : public QTextEdit {
 
@@ -27,6 +32,9 @@ public: // methods:
 
     void timerEvent(QTimerEvent * const event) override;
 
+    static QQuickItem const *
+    quickItemInFocus(QQuickWidget const * quickWidget, QPointF cursorPosition);
+
 private: // fields:
 
     int const m_updateTimerId;
