@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -73,13 +73,8 @@ BtFindWidget::BtFindWidget(QWidget * parent)
 
     // Case checkbox:
     m_caseCheckBox = new QCheckBox(this);
-    #if (QT_VERSION < QT_VERSION_CHECK(6, 7, 0))
-    BT_CONNECT(m_caseCheckBox, &QCheckBox::stateChanged,
-        this, &BtFindWidget::queueHighlight);
-    #else
     BT_CONNECT(m_caseCheckBox, &QCheckBox::checkStateChanged,
                this, &BtFindWidget::queueHighlight);
-    #endif
     widgetLayout->addWidget(m_caseCheckBox);
 
     // Spacer:
