@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -28,11 +28,7 @@ BtFontSizeWidget::BtFontSizeWidget(QWidget * parent)
     setValidator(m_validator);
     completer()->setCompletionMode(QCompleter::PopupCompletion);
 
-    #if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-    for (int const size : QFontDatabase().standardSizes()) {
-    #else
     for (int const size : QFontDatabase::standardSizes()) {
-    #endif
         if (size > m_validator->top())
             m_validator->setTop(size);
         addItem(QString::number(size), QVariant(size));
