@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -136,7 +136,10 @@ void BtQmlInterface::setSelection(int const column,
     }
 }
 
-void BtQmlInterface::clearSelection() noexcept { m_selection.reset(); }
+void BtQmlInterface::clearSelection() noexcept {
+    m_selection.reset();
+    Q_EMIT selectionChanged({});
+}
 
 QString BtQmlInterface::getSelectedText() const
 { return m_selection.has_value() ? m_selection->selectedText : QString(); }
