@@ -2,41 +2,30 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BT_DISPLAY_VIEW_INTERFACE_H
-#define BT_DISPLAY_VIEW_INTERFACE_H
+#pragma once
 
-#include <memory>
+#include <optional>
 #include <QFont>
 #include <QList>
 #include <QObject>
-#include <QMap>
+#include <QQmlEngine>
 #include <QString>
-#include <QTimer>
-#include "../../../backend/rendering/ctextrendering.h"
-#include "bttextfilter.h"
+#include "../../../backend/models/btmoduletextmodel.h"
 
 
 class CSwordKey;
 class CSwordModuleInfo;
-
-class QTimer;
+class CSwordVerseKey;
 class RoleItemModel;
 
-struct RefIndexes {
-    QString r1;
-    QString r2;
-    int index1;
-    int index2;
-};
-
 /**
  * /brief This class provides communications between QML and c++.
  *
@@ -47,12 +36,8 @@ struct RefIndexes {
 class BtQmlInterface : public QObject {
 
     Q_OBJECT
-
-    enum Format {
-        HTML,
-        Text
-    };
-    Q_PROPERTY(QString      activeLink              READ getActiveLink  NOTIFY activeLinkChanged    WRITE setActiveLink)
+    QML_ELEMENT
+    QML_SINGLETON
     Q_PROPERTY(QColor       backgroundColor         READ getBackgroundColor NOTIFY backgroundColorChanged)
     Q_PROPERTY(QColor       backgroundHighlightColor READ getBackgroundHighlightColor NOTIFY backgroundHighlightColorChanged)
     Q_PROPERTY(int          backgroundHighlightColorIndex READ getBackgroundHighlightColorIndex NOTIFY backgroundHighlightColorIndexChanged)
@@ -70,50 +55,60 @@ class BtQmlInterface : public QObject {
     Q_PROPERTY(QFont        font8                   READ getFont8   NOTIFY fontChanged)
     Q_PROPERTY(QFont        font9                   READ getFont9   NOTIFY fontChanged)
     Q_PROPERTY(QColor       foregroundColor         READ getForegroundColor NOTIFY foregroundColorChanged)
-    Q_PROPERTY(QString      highlightWords          READ getHighlightWords NOTIFY highlightWordsChanged)
     Q_PROPERTY(int          numModules              READ getNumModules NOTIFY numModulesChanged)
-    Q_PROPERTY(bool         pageDown                READ getPageDown   NOTIFY pageDownChanged)
-    Q_PROPERTY(bool         pageUp                  READ getPageUp     NOTIFY pageUpChanged)
     Q_PROPERTY(double       pixelsPerMM             READ getPixelsPerMM NOTIFY pixelsPerMMChanged)
     Q_PROPERTY(QVariant     textModel               READ getTextModel NOTIFY textModelChanged)
 
+public: /* Types: */
+
+    struct Selection {
+        int column;
+        int startIndex;
+        int endIndex;
+        QString selectedText;
+
+        friend bool operator==(Selection const & lhs, Selection const & rhs) {
+            return lhs.column == rhs.column
+                    && lhs.startIndex == rhs.startIndex
+                    && lhs.endIndex == rhs.endIndex
+                    && lhs.selectedText == rhs.selectedText;
+        }
+
+        friend bool operator!=(Selection const & lhs, Selection const & rhs) {
+            return lhs.column != rhs.column
+                    || lhs.startIndex != rhs.startIndex
+                    || lhs.endIndex != rhs.endIndex
+                    || lhs.selectedText != rhs.selectedText;
+        }
+    };
+
 public:
-    Q_INVOKABLE void cancelMagTimer();
+    void cancelMagTimer();
     Q_INVOKABLE void changeReference(int i);
-    Q_INVOKABLE void dragHandler(int index,const QString& link);
-    Q_INVOKABLE QString getRawText(int row, int column);
-    Q_INVOKABLE QStringList getModuleNames() const;
+    Q_INVOKABLE void dragHandler(int index);
     Q_INVOKABLE bool moduleIsWritable(int column);
-    Q_INVOKABLE void openContextMenu(int x, int y,int width);
     Q_INVOKABLE void openEditor(int row, int column);
-    Q_INVOKABLE void referenceChosen();
-    Q_INVOKABLE void setMagReferenceByUrl(const QString& url);
+    void setMagReferenceByUrl(const QString& url);
+    Q_INVOKABLE QString rawText(int row, int column);
     Q_INVOKABLE void setRawText(int row, int column, const QString& text);
-    Q_INVOKABLE void clearSelectedText();
-    Q_INVOKABLE bool hasSelectedText();
-    Q_INVOKABLE void saveSelectedText(int index, const QString& text);
-    Q_INVOKABLE void setBoundsMovement();
-    Q_INVOKABLE void setKeyFromLink(const QString& link);
-    Q_INVOKABLE bool shiftKeyDown();
+    Q_INVOKABLE void setBibleKey(const QString& link);
     Q_INVOKABLE int indexToVerse(int index);
+    Q_INVOKABLE void setHoveredLink(QString const & link);
 
-    BtQmlInterface(QObject *parent = nullptr);
-    ~BtQmlInterface();
+    BtQmlInterface(QObject * parent = nullptr);
+    ~BtQmlInterface() override;
 
-    int countHighlightsInItem(int index);
-    void findText(const QString& text, bool caseSensitive, bool backward);
-    void getNextMatchingItem(int index);
-    void getPreviousMatchingItem(int index);
+    void findText(bool backward);
 
-
-    QString getActiveLink() const;
+    QString const & activeLink() const noexcept { return m_activeLink; }
     QColor getBackgroundColor() const;
     QColor getBackgroundHighlightColor() const;
     QColor getForegroundColor() const;
     int getBackgroundHighlightColorIndex() const;
     void changeColorTheme();
-    void copyRange(int index1, int index2);
-    void copyVerseRange(const QString& ref1, const QString& ref2, const CSwordModuleInfo * module);
+    void copyRange(int index1, int index2) const;
+    static void copyVerseRange(CSwordVerseKey const & key1,
+                               CSwordVerseKey const & key2);
     QString getBibleUrlFromLink(const QString& url);
     int getContextMenuIndex() const;
     int getContextMenuColumn() const;
@@ -128,90 +123,79 @@ public:
     QFont getFont7() const;
     QFont getFont8() const;
     QFont getFont9() const;
-    QString getHighlightWords() const;
-    CSwordKey* getKey() const;
     CSwordKey* getMouseClickedKey() const;
     QString getLemmaFromLink(const QString& url);
     int getNumModules() const;
-    bool getPageDown() const;
-    bool getPageUp() const;
     double getPixelsPerMM() const;
-    QString getSelectedText();
+
+    Q_INVOKABLE void setSelection(int column,
+                                  int startIndex,
+                                  int endIndex,
+                                  QString const & selectedText);
+    Q_INVOKABLE void clearSelection() noexcept;
+    QString getSelectedText() const;
+
+    std::optional<Selection> const & selection() const noexcept
+    { return m_selection; }
+
     QVariant getTextModel();
     bool isBibleOrCommentary();
     BtModuleTextModel * textModel();
-    void pageDown();
-    void pageUp();
-    void referenceChoosen();
+    BtModuleTextModel const * textModel() const;
     void scrollToSwordKey(CSwordKey * key);
-    void setActiveLink(const QString& link);
     void setContextMenuIndex(int index);
     void setContextMenuColumn(int index);
-    void setFilterOptions(FilterOptions filterOptions);
     void setHighlightWords(const QString& words, bool caseSensitivy);
-    void setKey(CSwordKey* key);
     void setModules(const QStringList &modules);
     void settingsChanged();
 
-signals:
-    void activeLinkChanged();
+Q_SIGNALS:
     void backgroundColorChanged();
     void backgroundHighlightColorChanged();
     void backgroundHighlightColorIndexChanged();
     void contextMenuIndexChanged();
     void contextMenuColumnChanged();
-    void contextMenu(int x, int y, int moduleNum);
     void currentModelIndexChanged();
     void fontChanged();
     void foregroundColorChanged();
-    void highlightWordsChanged();
     void numModulesChanged();
-    void pageDownChanged();
-    void pageUpChanged();
     void pixelsPerMMChanged();
     void positionItemOnScreen(int index);
-    void referenceChange();
-    void newBibleReference(const QString& reference);
+    void setBibleReference(const QString& reference);
     void textChanged();
     void textModelChanged();
     void updateReference(const QString& reference);
     void dragOccuring(const QString& moduleName, const QString& keyName);
+    void activeLinkChanged(QString newActiveLink);
+    void selectionChanged(std::optional<Selection> newSelection);
 
-private slots:
-    void timeoutEvent();
-    void slotSetHighlightWords();
+protected: // Methods:
+
+    void timerEvent(QTimerEvent * event) final override;
 
 private:
-    void configModuleByType(const QString& type, const QStringList& availableModuleNames);
-    bool copyKey(CSwordKey const * const key, Format const format, bool const addText);
-    QString decodeLemma(const QString& value);
-    QString decodeMorph(const QString& value);
     QFont font(int column) const;
     void getFontsFromSettings();
     QString getReferenceFromUrl(const QString& url);
-    const CSwordModuleInfo* module() const;
-    std::unique_ptr<Rendering::CTextRendering> newRenderer(Format const format, bool const addText);
-    RefIndexes normalizeReferences(const QString& ref1, const QString& ref2);
-    QString stripHtml(const QString& html);
 
-    bool m_firstHref;
-    QTimer* m_linkTimer;
-    BtModuleTextModel* m_moduleTextModel;
-    CSwordKey* m_swordKey;
+public: // Fields:
+
+    static int typeId;
+
+private: // Fields:
+
+    bool m_firstHref = false;
+    int m_linkTimerId = 0;
+    BtModuleTextModel * const m_moduleTextModel;
+    CSwordKey * m_swordKey = nullptr;
 
     QList<QFont> m_fonts;
-    int m_backgroundHighlightColorIndex;
-    bool m_caseSensitive;
-    QString m_highlightWords;
+    int m_backgroundHighlightColorIndex = -1;
     QStringList m_moduleNames;
-    BtTextFilter m_textFilter;
     QString m_timeoutUrl;
     int m_contextMenuIndex;
     int m_contextMenuColumn;
     QString m_activeLink;
-    FindState m_findState;
-    QTimer m_timer;
-    QMap<int, QString> m_selectedText;
+    std::optional<FindState> m_findState;
+    std::optional<Selection> m_selection;
 };
-
-#endif
