@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -14,7 +14,6 @@
 
 #include <QAction>
 #include <Qt>
-#include <utility>
 #include "../../util/btconnect.h"
 #include "../../util/btmodules.h"
 #include "../displaywindow/cdisplaywindow.h"
@@ -53,7 +52,7 @@ void BtModuleChooserBar::adjustButtonCount(int const numButtons,
 
 BtModuleChooserButton *
 BtModuleChooserBar::addButton(CDisplayWindow * const window) {
-    BtModuleChooserButton* b = new BtModuleChooserButton(m_moduleType, this);
+    BtModuleChooserButton* b = new BtModuleChooserButton(*m_moduleType, this);
     QAction* a = addWidget(b);
     m_buttonList.append(b);
 
@@ -91,7 +90,7 @@ void BtModuleChooserBar::associateWithWindow(CDisplayWindow * const window) {
     for (int i = 0; i < modules.size(); i++) {
         addButton(window);
     }
-    if (!(m_moduleType == CSwordModuleInfo::GenericBook)) {
+    if (!(*m_moduleType == CSwordModuleInfo::GenericBook)) {
         addButton(window); // for ADD button
     } else {
         BT_ASSERT(modules.size() == 1);
