@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -14,7 +14,6 @@
 
 #include "../../backend/drivers/cswordmoduleinfo.h"
 #include "../../util/btconnect.h"
-#include "../../util/cresmgr.h"
 #include "btmodulechoosermenu.h"
 
 
@@ -29,36 +28,13 @@ BtModuleChooserButton::BtModuleChooserButton(CSwordModuleInfo::ModuleType mtype,
               | BtModuleChooserMenu::AddNoneButton,
               this))
 {
-    setIcon(icon());
+    setIcon(m_popup->buttonIcon());
     setMenu(m_popup);
     setPopupMode(QToolButton::InstantPopup);
     BT_CONNECT(m_popup, &BtModuleChooserMenu::sigModuleChosen,
                this,    &BtModuleChooserButton::moduleChosen);
 }
 
-QIcon const & BtModuleChooserButton::icon() {
-    switch (m_popup->moduleType()) {
-        case CSwordModuleInfo::Bible:
-            return m_popup->selectedModule()
-                    ? CResMgr::modules::bible::icon_unlocked()
-                    : CResMgr::modules::bible::icon_add();
-        case CSwordModuleInfo::Commentary:
-            return m_popup->selectedModule()
-                   ? CResMgr::modules::commentary::icon_unlocked()
-                   : CResMgr::modules::commentary::icon_add();
-        case CSwordModuleInfo::Lexicon:
-            return m_popup->selectedModule()
-                   ? CResMgr::modules::lexicon::icon_unlocked()
-                   : CResMgr::modules::lexicon::icon_add();
-        case CSwordModuleInfo::GenericBook:
-            return m_popup->selectedModule()
-                   ? CResMgr::modules::book::icon_unlocked()
-                   : CResMgr::modules::book::icon_add();
-        default: //return as default the bible icon
-            return CResMgr::modules::bible::icon_unlocked();
-    }
-}
-
 void BtModuleChooserButton::updateMenu(BtModuleList newModulesToUse,
                                        CSwordModuleInfo * newSelectedModule,
                                        int newButtonIndex,
@@ -73,11 +49,7 @@ void BtModuleChooserButton::updateMenu(BtModuleList newModulesToUse,
                     newSelectedModule,
                     newButtonIndex,
                     newLeftLikeModules);
-    if (newSelectedModule) {
-        setIcon(newSelectedModule->moduleIcon());
-    } else {
-        setIcon(icon());
-    }
+    setIcon(m_popup->buttonIcon());
 }
 
 /** Is called after a module was selected in the popup */
@@ -87,16 +59,16 @@ void BtModuleChooserButton::moduleChosen(
     if (m_popup->selectedModule()) { // If module was previously selected:
         if (newModule) {
             m_popup->setSelectedModule(newModule);
-            setIcon(newModule->moduleIcon());
+            setIcon(m_popup->buttonIcon());
             Q_EMIT sigModuleReplace(m_popup->buttonIndex(), newModule);
         } else {
             m_popup->setSelectedModule(nullptr);
-            setIcon(icon());
+            setIcon(m_popup->buttonIcon());
             Q_EMIT sigModuleRemove(m_popup->buttonIndex());
         }
     } else if (newModule) {
         m_popup->setSelectedModule(newModule);
-        setIcon(newModule->moduleIcon());
+        setIcon(m_popup->buttonIcon());
         Q_EMIT sigModuleAdd(m_popup->buttonIndex(), newModule);
     }
 }
