@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -62,11 +62,6 @@ class BtModuleChooserButton: public QToolButton {
         /** Handle the action signal from the menu. */
         void moduleChosen(CSwordModuleInfo * const module);
 
-    private:
-
-        /** Returns the icon used for the current status. */
-        QIcon const & icon();
-
     private:
 
         BtModuleChooserMenu * m_popup;
