@@ -2,24 +2,28 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BT_TOOLBAR_POPUP_ACTION_H
-#define BT_TOOLBAR_POPUP_ACTION_H
+#pragma once
 
 #include <QWidgetAction>
 
+#include <memory>
+#include <QIcon>
+#include <QObject>
+#include <QString>
+
+
+class QEvent;
+class QWidget;
 
-class QIcon;
 class QMenu;
-class QString;
-class QToolButton;
 
 // This class manages the toolbar display for going forward and backward in history.
 class BtToolBarPopupAction : public QWidgetAction {
@@ -37,16 +41,8 @@ class BtToolBarPopupAction : public QWidgetAction {
     protected:
         QWidget* createWidget(QWidget* parent) override;
 
-    private slots:
-
-// Slot to emit a triggered signal when the toolbar button is pressed
-        void buttonPressed();
-
     private:
-        QMenu* m_menu;
-        QToolButton* m_button;
+        std::unique_ptr<QMenu> const m_menu;
         QIcon m_icon;
         QString m_text;
 };
-
-#endif
