@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -28,7 +28,7 @@
 #include "../cmdiarea.h"
 #include "../display/btmodelviewreaddisplay.h"
 #include "../keychooser/ckeychooser.h"
-#include "btactioncollection.h"
+
 
 CBibleReadWindow::ActionCollection::ActionCollection(QObject * const parent)
     : CDisplayWindow::ActionCollection(parent)
@@ -184,6 +184,10 @@ void CBibleReadWindow::initActions() {
                            this,
                            &CBibleReadWindow::printAll);
 
+    #ifdef BUILD_TEXT_TO_SPEECH
+    m_actions.speakSelectedText = &ac->action("speakSelectedText");
+    #endif
+
     BT_CONNECT(displayWidget(), &BtModelViewReadDisplay::activeAnchorChanged,
                this,
                [this](QString const & newActiveAnchor) {
@@ -229,7 +233,12 @@ QMenu * CBibleReadWindow::newDisplayWidgetPopupMenu() {
     m_actions.printMenu->addAction(m_actions.print.reference);
     m_actions.printMenu->addAction(m_actions.print.chapter);
     popupMenu->addMenu(m_actions.printMenu);
-    return popupMenu;
+
+    #ifdef BUILD_TEXT_TO_SPEECH
+    popupMenu->addAction(m_actions.speakSelectedText);
+    #endif
+
+    return addDebugActions(popupMenu);
 }
 
 /** Moves to the next book. */
