@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -16,7 +16,6 @@
 
 #include <QAction>
 #include "../cexportmanager.h"
-#include "btactioncollection.h"
 
 
 class CSwordKey;
@@ -86,6 +85,10 @@ protected: // methods:
             QAction* chapter;
         }
         print;
+
+        #ifdef BUILD_TEXT_TO_SPEECH
+        QAction * speakSelectedText;
+        #endif
     }
     m_actions;
 
