@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -25,6 +25,7 @@
 #include "../../backend/managers/cswordbackend.h"
 #include "../../util/cresmgr.h"
 #include "../bibletime.h"
+#include "../bibletimeapp.h"
 #include "../cexportmanager.h"
 #include "../cmdiarea.h"
 #include "../display/btmodelviewreaddisplay.h"
@@ -95,6 +96,7 @@ CDisplayWindow::ActionCollection::ActionCollection(QObject * const parent)
                 CResMgr::displaywindows::general::backInHistory::icon(),
                 tr("Back in history"),
                 this);
+    action->setEnabled(false);
     action->setShortcut(CResMgr::displaywindows::general::backInHistory::accel);
     addAction(CResMgr::displaywindows::general::backInHistory::actionName,
               action);
@@ -103,6 +105,7 @@ CDisplayWindow::ActionCollection::ActionCollection(QObject * const parent)
                 CResMgr::displaywindows::general::forwardInHistory::icon(),
                 tr("Forward in history"),
                 this);
+    action->setEnabled(false);
     action->setShortcut(
                 CResMgr::displaywindows::general::forwardInHistory::accel);
     addAction(CResMgr::displaywindows::general::forwardInHistory::actionName,
@@ -129,6 +132,11 @@ CDisplayWindow::ActionCollection::ActionCollection(QObject * const parent)
     actn = new QAction(tr("Strong's Search"), this);
     actn->setShortcut(CResMgr::displaywindows::general::findStrongs::accel);
     addAction(CResMgr::displaywindows::general::findStrongs::actionName, actn);
+
+    #ifdef BUILD_TEXT_TO_SPEECH
+    actn = new QAction(tr("Speak selected text"), this);
+    addAction("speakSelectedText", actn);
+    #endif
 }
 
 CDisplayWindow::CDisplayWindow(BtModuleList const & modules,
@@ -153,6 +161,8 @@ CDisplayWindow::CDisplayWindow(BtModuleList const & modules,
     BT_ASSERT(m_swordKey);
     if (!key.isEmpty())
         m_swordKey->setKey(key);
+    m_history->add(m_swordKey.get());
+
     setMinimumSize(100, 100);
     setFocusPolicy(Qt::ClickFocus);
 
@@ -275,13 +285,29 @@ CDisplayWindow::CDisplayWindow(BtModuleList const & modules,
             initAddAction(QStringLiteral("copySelectedText"),
                           m_displayWidget,
                           &BtModelViewReadDisplay::copySelectedText);
+    auto hasSelection = m_displayWidget->qmlInterface()->selection().has_value();
+    copySelectedTextAction.setEnabled(hasSelection);
+    #ifdef BUILD_TEXT_TO_SPEECH
+    auto & speakSelectedTextAction =
+            initAddAction(QStringLiteral("speakSelectedText"),
+                          m_displayWidget,
+                          &BtModelViewReadDisplay::speakSelectedText);
+    speakSelectedTextAction.setEnabled(hasSelection);
+    #endif
     BT_CONNECT(m_displayWidget->qmlInterface(),
                &BtQmlInterface::selectionChanged,
                this,
-               [&copySelectedTextAction](
+               [&copySelectedTextAction
+                #ifdef BUILD_TEXT_TO_SPEECH
+                , &speakSelectedTextAction
+                #endif
+               ](
                  std::optional<BtQmlInterface::Selection> const & newSelection)
                {
                 copySelectedTextAction.setEnabled(newSelection.has_value());
+                #ifdef BUILD_TEXT_TO_SPEECH
+                speakSelectedTextAction.setEnabled(newSelection.has_value());
+                #endif
                });
     initAddAction(QStringLiteral("copyByReferences"),
                   m_displayWidget,
@@ -375,6 +401,11 @@ CDisplayWindow::CDisplayWindow(BtModuleList const & modules,
                 m_actions.copy.reference->setEnabled(hasActiveAnchor);
                 m_actions.print.reference->setEnabled(hasActiveAnchor);
                });
+    #ifdef BUILD_TEXT_TO_SPEECH
+    m_actions.speakSelectedText =
+            &m_actionCollection->action(QStringLiteral("speakSelectedText"));
+    #endif
+
     m_actionCollection->readShortcuts(
                 QStringLiteral("Displaywindow shortcuts"));
 }
@@ -551,7 +582,23 @@ QMenu * CDisplayWindow::newDisplayWidgetPopupMenu() {
     m_actions.printMenu->addAction(m_actions.print.reference);
     m_actions.printMenu->addAction(m_actions.print.entry);
     popupMenu->addMenu(m_actions.printMenu);
-    return popupMenu;
+
+    #ifdef BUILD_TEXT_TO_SPEECH
+    popupMenu->addAction((m_actions.speakSelectedText));
+    #endif
+
+    return addDebugActions(popupMenu);
+}
+
+QMenu * CDisplayWindow::addDebugActions(QMenu * const menu) {
+    if (btApp->debugMode()) {
+        auto * const debugAction =
+                new QAction(tr("DEBUG: Show raw text"), this);
+        debugAction->setProperty("bibletime_show_raw_text", true);
+        menu->addSeparator();
+        menu->addAction(debugAction);
+    }
+    return menu;
 }
 
 void CDisplayWindow::setupMainWindowToolBars() {
