@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -226,6 +226,8 @@ protected:
 
     virtual QMenu * newDisplayWidgetPopupMenu();
 
+    QMenu * addDebugActions(QMenu * menu);
+
     /** Called to add actions to mainWindow toolbars */
     virtual void setupMainWindowToolBars();
 
@@ -276,6 +278,9 @@ protected: // fields:
             QAction * reference;
             QAction * entry;
         } print;
+        #ifdef BUILD_TEXT_TO_SPEECH
+        QAction * speakSelectedText;
+        #endif
     } m_actions;
 
 private:
