@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -22,33 +22,15 @@
 #include <Qt>
 #include "../../util/btassert.h"
 #include "../../util/btconnect.h"
+#include "btlocationedit.h"
 #include "cscrollerwidgetset.h"
 
 
-class BtKeyLineEdit : public QLineEdit {
-
-public: // methods:
-
-    BtKeyLineEdit(QWidget * parent)
-        : QLineEdit(parent) {}
-
-protected: // methods:
-
-    void focusInEvent(QFocusEvent * event) override {
-        const Qt::FocusReason reason = event->reason();
-        if (reason == Qt::OtherFocusReason)
-            selectAll();
-        QWidget::focusInEvent(event);
-    }
-
-};
-
-
 CKCComboBox::CKCComboBox(QWidget * parent)
     : QComboBox(parent)
 {
     setFocusPolicy(Qt::WheelFocus);
-    setLineEdit(new BtKeyLineEdit(this));
+    setLineEdit(new BtLocationEdit(this));
     if (lineEdit())
         installEventFilter(lineEdit());
 }
