@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -15,7 +15,6 @@
 #include <QApplication>
 #include <QDebug>
 #include <QEvent>
-#include <QFocusEvent>
 #include <QHBoxLayout>
 #include <QLineEdit>
 #include <QMenu>
@@ -28,27 +27,11 @@
 #include "../../../backend/keys/cswordversekey.h"
 #include "../../../util/btconnect.h"
 #include "../../../util/cresmgr.h"
+#include "../btlocationedit.h"
 #include "../cscrollerwidgetset.h"
 #include "btdropdownchooserbutton.h"
 
 
-class BtLineEdit : public QLineEdit {
-    public:
-        BtLineEdit(QWidget* parent)
-                : QLineEdit(parent) {
-        }
-    protected:
-        void focusInEvent(QFocusEvent* event) override {
-            Qt::FocusReason reason = event->reason();
-            if (reason == Qt::OtherFocusReason) {
-                selectAll();
-            }
-
-            QWidget::focusInEvent(event);
-        }
-};
-
-
 BtBibleKeyWidget::BtBibleKeyWidget(
         CSwordBibleModuleInfo const * mod,
         CSwordVerseKey * key,
@@ -100,7 +83,7 @@ BtBibleKeyWidget::BtBibleKeyWidget(
 
     auto * const bookScroller = new CScrollerWidgetSet(this);
 
-    m_textbox = new BtLineEdit( this );
+    m_textbox = new BtLocationEdit(this);
     setFocusProxy(m_textbox);
     m_textbox->setContentsMargins(0, 0, 0, 0);
 
@@ -119,9 +102,7 @@ BtBibleKeyWidget::BtBibleKeyWidget(
 
     setTabOrder(m_textbox, nullptr);
 
-    // Using "this" instead of "nullptr" works around a Qt 5.9 bug, QTBUG-61213
     m_dropDownButtons = new QWidget(this);
-
     m_dropDownButtons->setWindowFlags(Qt::Popup);
     m_dropDownButtons->setAttribute(Qt::WA_WindowPropagation);
     m_dropDownButtons->setCursor(Qt::ArrowCursor);
@@ -270,11 +251,7 @@ bool BtBibleKeyWidget::eventFilter(QObject *o, QEvent *e) {
     }
 }
 
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-void BtBibleKeyWidget::enterEvent(QEvent *) {
-#else
 void BtBibleKeyWidget::enterEvent(QEnterEvent *) {
-#endif
     m_dropDownHoverTimer.stop();
 
     resetDropDownButtons();
