@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -39,11 +39,7 @@ class BtBibleKeyWidget : public QWidget  {
         void changed(CSwordVerseKey* key);
 
     protected:
-        #if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-        void enterEvent(QEvent * event) override;
-        #else
         void enterEvent(QEnterEvent * event) override;
-        #endif
         void leaveEvent(QEvent *event) override;
         void resizeEvent(QResizeEvent *event) override;
         void resetDropDownButtons();
