@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -135,16 +135,6 @@ void registerMetaTypes() {
     qRegisterMetaType<BtBookshelfTreeModel::Grouping>(
         "BtBookshelfTreeModel::Grouping");
 
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-    qRegisterMetaTypeStreamOperators<BtBookshelfTreeModel::Grouping>(
-        "BtBookshelfTreeModel::Grouping");
-    qRegisterMetaTypeStreamOperators<alignmentMode>("alignmentMode");
-    qRegisterMetaTypeStreamOperators<CSwordModuleSearch::SearchType>(
-        "SearchType");
-    qRegisterMetaTypeStreamOperators<BtConfig::StringMap>("StringMap");
-    qRegisterMetaTypeStreamOperators<QList<int> >("QList<int>");
-#endif
-
     BtQmlInterface::typeId =
         qmlRegisterSingletonType<BtQmlInterface>(
             "BibleTime",
@@ -205,26 +195,13 @@ int main(int argc, char* argv[]) {
     dir.setCurrent(homeSwordDir);
 #endif
 
-#ifdef Q_OS_MAC
-    // change to the user's sword dir containing the sword.conf config file, so that
-    // Sword will correctly find it.
-    QString homeSwordDir = util::directory::getUserHomeSwordDir().absolutePath();
-    QDir dir;
-    dir.setCurrent(homeSwordDir);
-#endif
-
     //first install QT's own translations
     QLocale const defaultLocale;
     QTranslator qtTranslator;
     if (qtTranslator.load(defaultLocale,
                           QStringLiteral("qt_"),
                           QString(),
-                          #if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-                          QLibraryInfo::location(
-                          #else
-                          QLibraryInfo::path(
-                          #endif
-                              QLibraryInfo::TranslationsPath)))
+                          QLibraryInfo::path(QLibraryInfo::TranslationsPath)))
         app.installTranslator(&qtTranslator);
     //then our own
     QTranslator bibleTimeTranslator;
