@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -18,7 +18,6 @@
 #include <QMap>
 #include <QTextStream>
 #include <QTextDocument>
-#include <QVector>
 #include <type_traits>
 #include <utility>
 #include "../../../backend/drivers/cswordmoduleinfo.h"
@@ -279,7 +278,7 @@ void CSearchAnalysisScene::saveAsHTML(QTextStream & out) const {
 
     out << QStringLiteral("</tr></table><p style=\"text-align:center;"
                           "font-size:x-small\">")
-        << tr("Created by <a href=\"https://bibletime.info/\">BibleTime</a>")
+        << tr("Created by <a href=\"%1\">BibleTime</a>").arg(BT_HOMEPAGE)
         << QStringLiteral("</p></body></html>");
 }
 
