@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -46,7 +46,7 @@ private: // methods:
 
 private Q_SLOTS:
 
-    void autoDeleteOrphanedIndicesChanged(int newState);
+    void autoDeleteOrphanedIndicesChanged(Qt::CheckState newState);
     void slotSwordSetupChanged();
     void createIndices();
     void deleteIndices();
