@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -20,7 +20,6 @@
 #include <QtAlgorithms>
 #include <QTreeWidget>
 #include <QTreeWidgetItem>
-#include <vector>
 #include "../../backend/config/btconfig.h"
 #include "../../backend/cswordmodulesearch.h"
 #include "../../backend/drivers/cswordmoduleinfo.h"
@@ -253,7 +252,7 @@ void CModuleResultView::setupTree(const CSwordModuleSearch::Results & results,
                                     QStringList(m->name())
                                     << QString::number(result.results.size()));
 
-        item->setIcon(0, util::tool::getIconForModule(m));
+        item->setIcon(0, m->moduleIcon());
         /*
           We need to make a decision here.  Either don't show any Strong's
           number translations, or show the first one in the search text, or
