@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -222,11 +222,7 @@ void CSearchResultView::contextMenuEvent(QContextMenuEvent* event) {
 
 
 QMimeData *
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-CSearchResultView::mimeData(QList<QTreeWidgetItem *> const items) const {
-#else
 CSearchResultView::mimeData(QList<QTreeWidgetItem *> const & items) const {
-#endif
     if (items.empty())
         return nullptr;
     BTMimeData::ItemList bookmarks;
