@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -12,20 +12,27 @@
 
 #include "btfontsettings.h"
 
-#include <set>
+#include <cstddef>
+#include <memory>
 #include <QCheckBox>
 #include <QComboBox>
+#include <QFont>
 #include <QFontDialog>
 #include <QGroupBox>
 #include <QHBoxLayout>
+#include <QIcon>
 #include <QLabel>
+#include <QNonConstOverload>
+#include <QPair>
+#include <Qt>
 #include <QVBoxLayout>
-#include <QWidget>
+#include <set>
 #include "../../backend/config/btconfig.h"
+#include "../../backend/language.h"
+#include "../../backend/managers/cswordbackend.h"
+#include "../../util/btassert.h"
 #include "../../util/btconnect.h"
 #include "../../util/cresmgr.h"
-#include "../../util/tool.h"
-#include "../bibletimeapp.h"
 #include "cconfigurationdialog.h"
 
 
@@ -36,8 +43,8 @@ BtFontSettingsPage::BtFontSettingsPage(CConfigurationDialog *parent)
     m_languageComboBox = new QComboBox(this);
     m_languageLabel->setBuddy(m_languageComboBox);
     m_languageCheckBox = new QCheckBox(this);
-    BT_CONNECT(m_languageCheckBox, SIGNAL(toggled(bool)),
-               this,               SLOT(useOwnFontClicked(bool)) );
+    BT_CONNECT(m_languageCheckBox, &QCheckBox::toggled,
+               this, &BtFontSettingsPage::useOwnFontClicked);
 
 
     QHBoxLayout *hLayout = new QHBoxLayout;
@@ -47,8 +54,8 @@ BtFontSettingsPage::BtFontSettingsPage(CConfigurationDialog *parent)
     hLayout->addWidget(m_languageCheckBox);
 
     struct Comp {
-        bool operator()(CLanguageMgr::Language const * lhs,
-                        CLanguageMgr::Language const * rhs) const
+        bool operator()(std::shared_ptr<Language const> const & lhs,
+                        std::shared_ptr<Language const> const & rhs) const
         {
             int cmp = lhs->translatedName().compare(rhs->translatedName());
             if (cmp == 0) {
@@ -58,12 +65,16 @@ BtFontSettingsPage::BtFontSettingsPage(CConfigurationDialog *parent)
             return cmp < 0;
         }
     };
-    std::set<CLanguageMgr::Language const *, Comp> languages;
-    for (auto const * const language
-         : CLanguageMgr::instance()->availableLanguages().values())
-        languages.emplace(language);
+    std::set<std::shared_ptr<Language const>, Comp> languages;
+    {
+        auto const availableLanguages =
+                CSwordBackend::instance().availableLanguages();
+        BT_ASSERT(availableLanguages);
+        for (auto const & language : *availableLanguages)
+            languages.emplace(language);
+    }
 
-    for (auto const * const l : languages) {
+    for (auto const & l : languages) {
         m_workSettings.emplace_back(
                     WorkSetting{*l, btConfig().getFontForLanguage(*l)});
         auto const & k = l->translatedName().isEmpty()
@@ -87,27 +98,30 @@ BtFontSettingsPage::BtFontSettingsPage(CConfigurationDialog *parent)
     */
     // m_fontChooser->setSampleText("SOMETHING");
 
-    BT_CONNECT(m_fontChooser, &QFontDialog::currentFontChanged,
-               [this](QFont const & newFont) {
-                   auto & work =
-                           m_workSettings[m_languageComboBox->currentIndex()];
-                   work.settings.second = newFont;
-               });
-    BT_CONNECT(m_languageComboBox,
-               QOverload<int>::of(&QComboBox::currentIndexChanged),
-               [this](int const newIndex) {
-                   auto const i = static_cast<std::size_t>(newIndex);
-                   auto const & p = m_workSettings[i].settings;
-                   useOwnFontClicked(p.first);
-                   m_languageCheckBox->setChecked(p.first);
-                   m_fontChooser->setCurrentFont(p.second);
-               });
+    if (m_languageComboBox->count() > 0) {
+        BT_CONNECT(m_fontChooser, &QFontDialog::currentFontChanged,
+                   [this](QFont const & newFont) {
+            auto & work =
+                    m_workSettings[m_languageComboBox->currentIndex()];
+            work.settings.second = newFont;
+        });
+        BT_CONNECT(m_languageComboBox,
+                   qOverload<int>(&QComboBox::currentIndexChanged),
+                   [this](int const newIndex) {
+            auto const i = static_cast<std::size_t>(newIndex);
+            auto const & p = m_workSettings[i].settings;
+            useOwnFontClicked(p.first);
+            m_languageCheckBox->setChecked(p.first);
+            m_fontChooser->setCurrentFont(p.second);
+        });
+
+        auto const & v =
+                m_workSettings[m_languageComboBox->currentIndex()].settings;
+        m_fontChooser->setCurrentFont(v.second);
+        useOwnFontClicked(v.first);
+        m_languageCheckBox->setChecked(v.first);
+    }
 
-    auto const & v =
-            m_workSettings[m_languageComboBox->currentIndex()].settings;
-    m_fontChooser->setCurrentFont(v.second);
-    useOwnFontClicked(v.first);
-    m_languageCheckBox->setChecked(v.first);
     m_fontChooser->setMinimumSize(m_fontChooser->sizeHint());
 
     QVBoxLayout *fLayout = new QVBoxLayout;
