@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -15,6 +15,7 @@
 #include <QByteArray>
 #include "../../backend/config/btconfig.h"
 #include "btfontsettings.h"
+#include "bttexttospeechsettings.h"
 #include "cacceleratorsettings.h"
 #include "cdisplaysettings.h"
 #include "cswordsettings.h"
@@ -35,6 +36,9 @@ CConfigurationDialog::CConfigurationDialog(QWidget * const parent,
     addPage(new CSwordSettingsPage(this));
     addPage(new BtFontSettingsPage(this));
     addPage(new CAcceleratorSettingsPage(this));
+    #ifdef BUILD_TEXT_TO_SPEECH
+    addPage(new BtTextToSpeechSettingsPage(this));
+    #endif
 
     restoreGeometry(btConfig().value<QByteArray>(GeometryKey, QByteArray()));
 }
