@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -14,9 +14,9 @@
 
 #include "btconfigdialog.h"
 
+#include <QList>
 #include <QObject>
 #include <QString>
-#include <QVector>
 
 
 class CConfigurationDialog;
@@ -46,7 +46,7 @@ class CDisplaySettingsPage: public BtConfigDialog::Page {
 
     private: // methods:
 
-        static QVector<QString> bookNameAbbreviationsTryVector();
+        static QList<QString> bookNameAbbreviationsTryVector();
         void initSwordLocaleCombo();
 
     private: // fields:
