@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -139,14 +139,12 @@ BtIcons::BtIcons()
     , icon_lock(QStringLiteral("lock.svg"))
     , icon_manual(QStringLiteral("manual.svg"))
     , icon_map(QStringLiteral("map.svg"))
-    , icon_pencil(QStringLiteral("pencil.svg"))
     , icon_plus(QStringLiteral("plus.svg"))
     , icon_pointing_arrow(QStringLiteral("pointing_arrow.svg"))
     , icon_print(QStringLiteral("print.svg"))
     , icon_remove(QStringLiteral("remove.svg"))
     , icon_questionable(QStringLiteral("questionable.svg"))
-    , icon_questionmark(QStringLiteral("questionmark.svg"))
-    , icon_refresh(QStringLiteral("refresh.svg"))
+    , icon_speaker(QStringLiteral("speaker.svg"))
     , icon_startconfig(QStringLiteral("startconfig.svg"))
     , icon_stop(QStringLiteral("stop.svg"))
     , icon_swordconfig(QStringLiteral("swordconfig.svg"))
@@ -170,18 +168,24 @@ BtIcons::BtIcons()
     , icon_window_fullscreen(QStringLiteral("window_fullscreen.svg"))
     /* Overlayed icons: */
     , icon_bible_add(icon_bible, icon_add)
-    , icon_bible_install(icon_bible, icon_plus)
     , icon_bible_locked(icon_bible, icon_lock)
     , icon_bible_remove(icon_bible, icon_remove)
-    , icon_bible_uninstall(icon_bible, icon_delete)
     , icon_book_add(icon_book, icon_add)
     , icon_book_locked(icon_book, icon_lock)
+    , icon_calendar_add(icon_calendar, icon_add)
+    , icon_calendar_locked(icon_calendar, icon_lock)
     , icon_cascade_auto(icon_cascade, icon_automatically)
     , icon_commentary_add(icon_commentary, icon_add)
     , icon_commentary_locked(icon_commentary, icon_lock)
+    , icon_dictionary_add(icon_dictionary, icon_add)
+    , icon_dictionary_locked(icon_dictionary, icon_lock)
     , icon_folder_add(icon_folder, icon_add)
     , icon_lexicon_add(icon_lexicon, icon_add)
     , icon_lexicon_locked(icon_lexicon, icon_lock)
+    , icon_map_add(icon_map, icon_add)
+    , icon_map_locked(icon_map, icon_lock)
+    , icon_questionable_add(icon_questionable, icon_add)
+    , icon_questionable_locked(icon_questionable, icon_lock)
     , icon_tile_auto(icon_tile, icon_automatically)
     , icon_tile_horiz_auto(icon_tile_horiz, icon_automatically)
     , icon_tile_vert_auto(icon_tile_vert, icon_automatically)
