@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -12,7 +12,6 @@
 
 #pragma once
 
-#include <cstddef>
 #include <QtGlobal>
 #include <QString>
 
@@ -32,18 +31,10 @@ namespace directory {
 */
 bool initDirectoryCache();
 
-/** Returns the size of the directory including the size of all its files
- * and its subdirs.
- *
- * \todo Check if it's suitable for huge dir trees, as it holds a QDir object
- * for each of it at the same time in the deepest recursion.
- * For really deep dir tree this may lead to a stack overflow.
- *
- * @return The size of the dir in bytes
- */
+/** \returns the total size of all files in the given directory, recursively. */
 ::qint64 getDirSizeRecursive(QString const & dir);
 
-#if defined(Q_OS_WIN) // Windows only directory
+#ifdef Q_OS_WIN
 /** Return the path to the sword dir., Windows only
     C:\Program Files\BibleTime\share\sword
  */
@@ -51,12 +42,6 @@ const QDir &getApplicationSwordDir();
 
 /** Return the path to the shared Sword directory */
 const QDir &getSharedSwordDir();
-
-#elif defined(Q_OS_MAC) // Mac only directories
-/**
- * Path to the Sword locales
- */
-const QDir &getSwordLocalesDir();
 #endif
 
 /** Return the path to the icons. */
