@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -24,9 +24,7 @@
 #include <QObject>
 #include <QTextStream>
 #include <QWidget>
-#include "../backend/drivers/cswordmoduleinfo.h"
 #include "btassert.h"
-#include "cresmgr.h"
 
 
 namespace util {
@@ -77,42 +75,6 @@ bool savePlainFile(QString const & filename, QString const & text)
     return savePlainFile(filename, *writer, &userData);
 }
 
-QIcon const & getIconForModule(const CSwordModuleInfo * const module) {
-    if (!module)
-        return CResMgr::modules::book::icon_locked();
-
-    if (module->category() == CSwordModuleInfo::Cult)
-        return CResMgr::modules::icon_cult();
-
-    switch (module->type()) {
-        case CSwordModuleInfo::Bible:
-            if (module->isLocked())
-                return CResMgr::modules::bible::icon_locked();
-            return CResMgr::modules::bible::icon_unlocked();
-
-        case CSwordModuleInfo::Lexicon:
-            if (module->isLocked())
-                return CResMgr::modules::lexicon::icon_locked();
-            return CResMgr::modules::lexicon::icon_unlocked();
-
-        case CSwordModuleInfo::Commentary:
-            if (module->isLocked())
-                return CResMgr::modules::commentary::icon_locked();
-            return CResMgr::modules::commentary::icon_unlocked();
-
-        case CSwordModuleInfo::GenericBook:
-            if (module->isLocked())
-                return CResMgr::modules::book::icon_locked();
-            return CResMgr::modules::book::icon_unlocked();
-
-        case CSwordModuleInfo::Unknown: //fallback
-        default:
-            if (module->isLocked())
-                return CResMgr::modules::book::icon_locked();
-            return CResMgr::modules::book::icon_unlocked();
-    }
-}
-
 void initExplanationLabel(QLabel * const label,
                           const QString & heading,
                           const QString & text)
