@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2025 by the BibleTime developers.
+* Copyright 1999-2026 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -49,12 +49,6 @@ bool savePlainFile(QString const & filename,
 */
 bool savePlainFile(QString const & filename, QString const & text);
 
-/**
-  \param[in] module the module whose icon to return.
-  \returns the icon used for the a module.
-*/
-QIcon const & getIconForModule(const CSwordModuleInfo * module);
-
 /**
   \brief Initializes a QLabel to explain difficult things of dialogs.
 
